@@ -1,15 +1,18 @@
 from .SURE import SURE
 from .DensityFlow import DensityFlow
+from .DensityFlowLinear import DensityFlowLinear
 from .PerturbE import PerturbE
 from .TranscriptomeDecoder import TranscriptomeDecoder
 from .SimpleTranscriptomeDecoder import SimpleTranscriptomeDecoder
 from .EfficientTranscriptomeDecoder import EfficientTranscriptomeDecoder 
 from .VirtualCellDecoder import VirtualCellDecoder
+from .PerturbationAwareDecoder import PerturbationAwareDecoder
 
 from . import utils 
 from . import codebook
 from . import SURE
 from . import DensityFlow
+from . import DensityFlowLinear
 from . import atac
 from . import flow 
 from . import perturb
@@ -18,6 +21,8 @@ from . import TranscriptomeDecoder
 from . import SimpleTranscriptomeDecoder
 from . import EfficientTranscriptomeDecoder
 from . import VirtualCellDecoder
+from . import PerturbationAwareDecoder
 
-__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'SimpleTranscriptomeDecoder',
-           'EfficientTranscriptomeDecoder', 'VirtualCellDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
+__all__ = ['SURE', 'DensityFlow', 'DensityFlowLinear', 'PerturbE', 'TranscriptomeDecoder', 'SimpleTranscriptomeDecoder',
+           'EfficientTranscriptomeDecoder', 'VirtualCellDecoder', 'PerturbationAwareDecoder', 
+           'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
